marktools.is_component_with_annotation_attached
===============================================

.. autofunction:: abjad.tools.marktools.is_component_with_annotation_attached.is_component_with_annotation_attached
